GO-2025-3789 : Snyk CLI Insertion of Sensitive Information into Log File allowed in DEBUG or DEBUG/TRACE mode in github.com/snyk/go-application-framework
Discover Packages
github.com/snyk/go-application-framework
pkg
utils
conversion
package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jun 5, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func ToInt(value interface{}) (int , error )
ToInt converts an interface{} value to int interpreting strings and float values as base 10 integers
ToInt64 converts an interface{} value to int64 interpreting strings and float values as base 10 integers
Source Files
¶
Click to show internal directories.
Click to hide internal directories.